import React from 'react';
import classnames from 'classnames';
import copy from 'copy-to-clipboard';

import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faCopy } from '@fortawesome/free-solid-svg-icons';

import { styles } from './styles.scss';

const TD = props => {
  const value = props.value || props.children;
  return (
    <td onClick={() => copy(value)}>
      {props.children}
      <FontAwesomeIcon icon={faCopy} />
    </td>
  );
};

const Table = (props) => {
  const { name, colors, reference, minor, noCSS } = props;

  if (Array.isArray(colors)) {
    return (
      <div className={classnames('table', styles)}>
        <h2 className={classnames({ minor })}>{name} (<code>{reference}</code>)</h2>
        <table className='ramp'>
          <tbody>
            {colors.map(c =>
              <tr key={c}>
                <TD value={c}>
                  <span className='swatch' style={{ backgroundColor: c }} />
                </TD>
              </tr>
            )}
          </tbody>
        </table>
      </div>
    );
  } else {
    return (
      <div className={classnames('table', styles)}>
        <h2>{name} (<code>{reference}</code>)</h2>
        <table>
          <thead>
            <tr>
              <th>JavaScript</th>

              {!noCSS &&
                <th>SCSS</th>
              }

              <th>Value</th>
            </tr>
          </thead>
          <tbody>
            {Object.keys(colors).map(k => {
              if (Array.isArray(colors[k]) || typeof colors[k] === 'object') {
                return null;
              } else {
                return (
                  <tr key={k}>
                    <TD>{k}</TD>

                    {!noCSS &&
                    <TD>{`$${k.toLowerCase().replace(/_/g, '-')}`}</TD>
                    }

                    <TD value={colors[k]}>
                      <span className='swatch' style={{ backgroundColor: colors[k] }} />
                      <span>{colors[k]}</span>
                    </TD>
                  </tr>
                );
              }
            })}
          </tbody>
        </table>
      </div>
    );
  }
};

Table.defaultProps = {
  noCSS: false,
  minor: false,
};

export default Table;
