import React, { useEffect } from 'react';
import { Helmet as DefaultHelmet } from 'react-helmet';

import initUtag from './utag';

const Head = props => {
  const { helmet: Helmet, trackView } = props;

  useEffect(() => {
    if (!props['no-utag'] && window.UTAG_SCRIPTS_LOADED === true) {
      trackView(props.utag.pageName);
    }
  }, [props.utag.pageName, trackView, props['no-utag']]);

  useEffect(() => {
    if (!props['no-utag']) {
      initUtag(props.utag);
    }
  }, [props.utag, props['no-utag']]);

  return (
    <Helmet>

      {!props['no-html'] &&
        <html lang='en' dir='ltr' />
      }

      {(props.title || props.pageName) &&
        <title>{props.seo.title || props.title || props.pageName}</title>
      }

      {!props['no-favicon'] && [
        <link key='apple-touch-icon:60x60' rel='apple-touch-icon' sizes='60x60' href='https://www.politico.com/interactives/cdn/images/icon-set/apple-icon-60x60.png' />,
        <link key='apple-touch-icon:72x72' rel='apple-touch-icon' sizes='72x72' href='https://www.politico.com/interactives/cdn/images/icon-set/apple-icon-72x72.png' />,
        <link key='apple-touch-icon:76x76' rel='apple-touch-icon' sizes='76x76' href='https://www.politico.com/interactives/cdn/images/icon-set/apple-icon-76x76.png' />,
        <link key='apple-touch-icon:114x114' rel='apple-touch-icon' sizes='114x114' href='https://www.politico.com/interactives/cdn/images/icon-set/apple-icon-114x114.png' />,
        <link key='apple-touch-icon:120x120' rel='apple-touch-icon' sizes='120x120' href='https://www.politico.com/interactives/cdn/images/icon-set/apple-icon-120x120.png' />,
        <link key='apple-touch-icon:144x144' rel='apple-touch-icon' sizes='144x144' href='https://www.politico.com/interactives/cdn/images/icon-set/apple-icon-144x144.png' />,
        <link key='apple-touch-icon:152x152' rel='apple-touch-icon' sizes='152x152' href='https://www.politico.com/interactives/cdn/images/icon-set/apple-icon-152x152.png' />,
        <link key='apple-touch-icon:180x180' rel='apple-touch-icon' sizes='180x180' href='https://www.politico.com/interactives/cdn/images/icon-set/apple-icon-180x180.png' />,
        <link key='icon:32x32' rel='icon' sizes='32x32' type='image/png' href='https://www.politico.com/interactives/cdn/images/icon-set/favicon-32x32.png' />,
        <link key='icon:192x192' rel='icon' sizes='192x192' type='image/png' href='https://www.politico.com/interactives/cdn/images/icon-set/android-icon-192x192.png' />,
        <link key='icon:96x96' rel='icon' sizes='96x96' type='image/png' href='https://www.politico.com/interactives/cdn/images/icon-set/favicon-96x96.png' />,
        <link key='icon:16x16' rel='icon' sizes='16x16' type='image/png' href='https://www.politico.com/interactives/cdn/images/icon-set/favicon-16x16.png' />,
      ]}

      {!props['no-meta'] && [
        <meta key='charSet' charSet='utf-8' />,
        <meta key="httpEquiv='Content-Type'" httpEquiv='Content-Type' content='text/html; charset=UTF-8' />,
        <meta key="httpEquiv='X-UA-Compatible'" httpEquiv='X-UA-Compatible' content='IE=edge,chrome=1' />,
        <meta key='viewport' name='viewport' content='width=device-width, initial-scale=1' />,
      ]}

      {props.publishPath && !props['no-canonical'] && [
        <meta key='og:url' property='og:url' content={`https://politico.com/${props.publishPath}`} />,
        <link key='canonical' rel='canonical' href={`https://politico.com/${props.publishPath}`} />,
      ]}

      {props.social && [
        <meta key='description' name='description' content={props.social.twitter.card_description} />,
        <meta key='twitter:card' property='twitter:card' content='summary_large_image' />,
        <meta key='og:type' property='og:type' content='article' />,
        <meta property='article:opinion' content={props.opinion} />,
        <meta key='twitter:site' property='twitter:site' content='@politico' />,
        <meta key='twitter:creator' property='twitter:creator' content='@politico' />,
        <meta key='article:author' property='article:author' content='https://www.facebook.com/politico' />,
        <meta key='fb:app_id' property='fb:app_id' content='114037015331397' />,
        <meta key='twitter:title' property='twitter:title' content={props.social.twitter.card_title} />,
        <meta key='og:title' property='og:title' content={props.social.fbook.card_title} />,
        <meta key='twitter:description' property='twitter:description' content={props.social.twitter.card_description} />,
        <meta key='og:description' property='og:description' content={props.social.fbook.card_description} />,
        <meta key='twitter:image' property='twitter:image' content={props.social.image.url} />,
        <meta key='twitter:image:alt' property='twitter:image:alt' content={props.social.twitter.card_title} />,
        <meta key='og:image' property='og:image' content={props.social.image.url} />,
        <meta key='og:image:type' property='og:image:type' content={props.social.image.type} />,
        <meta key='og:image:width' property='og:image:width' content={props.social.image.width} />,
        <meta key='og:image:height' property='og:image:height' content={props.social.image.height} />,
      ]}

      {!props['no-battletoads'] &&
        <link key='battletoads' rel='stylesheet' type='text/css' href='https://www.politico.com/interactives/cdn/fonts/battletoads/icons/politico-battletoads-icons.min.css' />
      }

      {!props['no-fontawesome'] &&
        <link key='fontawesome' rel='stylesheet' href='https://use.fontawesome.com/releases/v5.3.1/css/all.css' integrity='sha384-mzrmE5qonljUremFsqc01SB46JvROS7bZs3IO2EmfFsd15uHvIt+Y8vEf7N7fWAU' crossOrigin='anonymous' />
      }

      {!props['no-typekit'] && props['site'] === 'magazine' && [
        <link key='jubilat' rel='stylesheet' href='https://use.typekit.net/bvr3gvp.css' />,
      ]}

      {!props['no-typekit'] && [
        <link key='typekit' rel='stylesheet' href='https://use.typekit.net/dsx2uhv.css' />,
        <script key='typekit-script'>{`try{Typekit.load({ async: true });}catch(e){}`}</script>,
      ]}

      { props.children }
    </Helmet>
  );
};

Head.defaultProps = {
  title: null,
  publishPath: null,

  utag: {
    activate: true,
    pageName: '',
    appName: '',
    siteSection: 'politics',
    adUnitSection: 'politics',
    contentTag: undefined,
    pageType: 'interactives',
    pageSubType: undefined,

    authors: [
      {
        link: 'https://www.politico.com/',
        name: 'POLITICO Staff',
      },
    ],
  },

  seo: {
    title: '',
    description: '',
  },

  social: {
    fbook: {
      card_title: '',
      card_description: '',
    },
    twitter: {
      card_title: '',
      share_tweet: '',
      card_description: '',
    },
    image: {
      url: '',
      alt: '<Text>',
      type: 'image/jpeg',
      width: '600',
      height: '300',
    },
  },

  opinion: false,
  site: 'core',

  trackView: () => null,
  helmet: DefaultHelmet,

  'no-html': false,
  'no-title': false,
  'no-favicon': false,
  'no-canonical': false,
  'no-meta': false,
  'no-social': false,
  'no-battletoads': false,
  'no-fontawesome': false,
  'no-typekit': false,
  'no-jquery': false,
  'no-adBlockCookie': false,
  'no-utag': false,
};

export default Head;
